@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
  * USA
  *
  */
@@ -45,10 +45,11 @@
 #include "config.h"
 
 extern char *Program;
-static char *StrConvertEncoding(char *str,char *from,char *to,int max_len);
+static char *StrConvertEncoding(char *str,const char *from,
+                                const char *to,int max_len);
 gboolean DiscDBUTF8Validate(const DiscInfo *disc,const DiscData *data);
 static void DiscDBConvertEncoding(DiscInfo *disc,DiscData *data,
-                                  char *from,char *to);
+                                  const char *from,const char *to);
 static int DiscDBSum(int val);
 static char *DiscDBReadLine(char **dataptr);
 static GString *DiscDBMakeURI(DiscDBServer *server,DiscDBHello *hello,
@@ -157,7 +158,7 @@ static GString *DiscDBMakeURI(DiscDBServer *server,DiscDBHello *hello,
 
   uri=g_string_new(NULL);
 
-  g_string_sprintf(uri,"http://%s/%s?cmd=%s&hello=private+free.the.cddb+%s+%s"
+  g_string_printf(uri,"http://%s/%s?cmd=%s&hello=private+free.the.cddb+%s+%s"
 		   "&proto=%d",
 		   server->name,server->cgi_prog,cmd,
 		   hello->hello_program,hello->hello_version,
@@ -170,7 +171,8 @@ static char *DiscDBMakeRequest(DiscDBServer *server,DiscDBHello *hello,
 			       char *cmd)
 {
   GString *uri;
-  GString *proxy,*user;
+  GString *proxy=NULL;
+  GString *user=NULL;
   char user_agent[256];
   struct curl_slist *headers=NULL;
   FILE *outfile;
@@ -186,7 +188,7 @@ static char *DiscDBMakeRequest(DiscDBServer *server,DiscDBHello *hello,
     if(server->use_proxy) {
       proxy=g_string_new(NULL);
 
-      g_string_sprintf(proxy,"%s:%d",server->proxy->name,
+      g_string_printf(proxy,"%s:%d",server->proxy->name,
                        server->proxy->port);
       
       curl_easy_setopt(curl_handle,CURLOPT_PROXY,proxy->str);
@@ -195,7 +197,7 @@ static char *DiscDBMakeRequest(DiscDBServer *server,DiscDBHello *hello,
 
         user=g_string_new(NULL);
 
-        g_string_sprintf(user,"%s:%s",server->proxy->username,
+        g_string_printf(user,"%s:%s",server->proxy->username,
                          server->proxy->pswd);
         
         curl_easy_setopt(curl_handle,CURLOPT_PROXYUSERPWD,user->str);
@@ -230,9 +232,8 @@ static char *DiscDBMakeRequest(DiscDBServer *server,DiscDBHello *hello,
         data=(char *)malloc(filesize+1);
         
         if(data) {
-          fread(data,filesize,1,outfile);
-
-          data[filesize]='\0';
+          if (fread(data,filesize,1,outfile) > 0)
+            data[filesize]='\0';
         }
       }
       
@@ -246,10 +247,12 @@ static char *DiscDBMakeRequest(DiscDBServer *server,DiscDBHello *hello,
     g_string_free(uri,TRUE);
 
     if(server->use_proxy) {
-      g_string_free(proxy,TRUE);
+      if (proxy)
+        g_string_free(proxy,TRUE);
 
       if(*server->proxy->username) {
-        g_string_free(user,TRUE);
+        if (user)
+          g_string_free(user,TRUE);
       }
     }
   }
@@ -276,13 +279,13 @@ gboolean DiscDBDoQuery(DiscInfo *disc,DiscDBServer *server,
 
   cmd=g_string_new(NULL);
 
-  g_string_sprintfa(cmd,"cddb+query+%08x+%d",DiscDBDiscid(disc),
+  g_string_printf(cmd,"cddb+query+%08x+%d",DiscDBDiscid(disc),
 		    disc->num_tracks);
 
   for(index=0;index<disc->num_tracks;index++)
-    g_string_sprintfa(cmd,"+%d",disc->track[index].start_frame);
+    g_string_append_printf(cmd,"+%d",disc->track[index].start_frame);
 
-  g_string_sprintfa(cmd,"+%d",disc->length.mins*60 + disc->length.secs);
+  g_string_append_printf(cmd,"+%d",disc->length.mins*60 + disc->length.secs);
 
   Debug(_("Query is [%s]\n"),cmd->str);
 
@@ -496,7 +499,8 @@ static void DiscDBProcessLine(char *inbuffer,DiscData *data,
   }
 }
 
-static char *StrConvertEncoding(char *str,char *from,char *to,int max_len)
+static char *StrConvertEncoding(char *str,const char *from,
+                                const char *to,int max_len)
 {
   char *conv_str;
   gsize rb,wb;
@@ -541,7 +545,7 @@ gboolean DiscDBUTF8Validate(const DiscInfo *disc,const DiscData *data)
 
 
 static void DiscDBConvertEncoding(DiscInfo *disc,DiscData *data,
-                                  char *from,char *to)
+                                  const char *from,const char *to)
 {
   int track;
 
@@ -587,7 +591,7 @@ gboolean DiscDBRead(DiscInfo *disc,DiscDBServer *server,
 
   cmd=g_string_new(NULL);
 
-  g_string_sprintf(cmd,"cddb+read+%s+%08x",DiscDBGenre(entry->entry_genre),
+  g_string_printf(cmd,"cddb+read+%s+%08x",DiscDBGenre(entry->entry_genre),
 		   entry->entry_id);
 
   result=DiscDBMakeRequest(server,hello,cmd->str);
@@ -633,9 +637,9 @@ gboolean DiscDBStatDiscData(DiscInfo *disc)
   if(!disc->have_info) CDStat(disc,TRUE);
 
   id=DiscDBDiscid(disc);
-  
-  g_snprintf(root_dir,256,"%s/.cddb",getenv("HOME"));
-  
+
+  g_snprintf(root_dir, 256, "%s/.cddb", g_get_home_dir());
+
   if(stat(root_dir, &st) < 0)
     return FALSE;
   else {
@@ -664,9 +668,9 @@ int DiscDBReadDiscData(DiscInfo *disc,DiscData *ddata, const char *encoding)
   int index,genre;
   char root_dir[256],file[256],inbuf[512];
   struct stat st;
-  
-  g_snprintf(root_dir,256,"%s/.cddb",getenv("HOME"));
-  
+
+  g_snprintf(root_dir, 256, "%s/.cddb", g_get_home_dir());
+
   if(stat(root_dir, &st) < 0) {
     return -1;
   } else {
@@ -780,7 +784,7 @@ int DiscDBWriteDiscData(DiscInfo *disc,DiscData *ddata,FILE *outfile,
   if(!disc->have_info) CDStat(disc,TRUE);
 
   if(!outfile) {
-    g_snprintf(root_dir,256,"%s/.cddb",getenv("HOME"));
+    g_snprintf(root_dir, 256, "%s/.cddb", g_get_home_dir());
     g_snprintf(file,256,"%s/%08x",root_dir,ddata->data_id);
   
     if(stat(root_dir,&st)<0) {
@@ -807,13 +811,8 @@ int DiscDBWriteDiscData(DiscInfo *disc,DiscData *ddata,FILE *outfile,
   }
   else discdb_data=outfile;
 
-#ifndef GRIPCD
   fprintf(discdb_data,"# xmcd CD database file generated by Grip %s\n",
 	  VERSION);
-#else
-  fprintf(discdb_data,"# xmcd CD database file generated by GCD %s\n",
-	  VERSION);
-#endif
   fputs("# \n",discdb_data);
   fputs("# Track frame offsets:\n",discdb_data);
 
