@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU Lesser General Public
  *  License along with this library; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  *
  *  concept and filter values by David Robinson (David@Robinson.org)
  *    -- blame him if you think the idea is flawed
@@ -98,10 +98,20 @@ typedef signed int      Int32_t;
 #define YULE_ORDER         10
 #define BUTTER_ORDER        2
 #define RMS_PERCENTILE      0.95        // percentile which is louder than the proposed level
-#define MAX_SAMP_FREQ   48000.          // maximum allowed sample frequency [Hz]
-#define RMS_WINDOW_TIME     0.050       // Time slice size [s]
-#define STEPS_per_dB      100.          // Table entries per dB
-#define MAX_dB            120.          // Table entries for 0...MAX_dB (normal max. values are 70...80 dB)
+// This used to be 48000 and 0.050.
+// It changed to 480 and 5 as it is only needed to determine the
+// size of the arrays below (lstepbuf, loutbuf, rstepbuf, routbuf).
+// Current compilers give the following warnings without this change:
+//   warning: variably modified ‘lstepbuf’ at file scope
+// This silences the compiler warning and should not change the actual
+// size of the array.
+#define MAX_SAMP_FREQ   480          // maximum allowed sample frequency [Hz]
+#define RMS_WINDOW_TIME     5       // Time slice size [s] - adapted to MAX_SAMP_FREQ
+#define RMS_WINDOW_TIME_FLOAT 0.05       // Time slice size [s] - original value
+// The following two defines were also float and have been changed to
+// non-float for the same reason as above.
+#define STEPS_per_dB      100          // Table entries per dB
+#define MAX_dB            120          // Table entries for 0...MAX_dB (normal max. values are 70...80 dB)
 
 #define MAX_ORDER               (BUTTER_ORDER > YULE_ORDER ? BUTTER_ORDER : YULE_ORDER)
 #define MAX_SAMPLES_PER_WINDOW  (size_t) (MAX_SAMP_FREQ * RMS_WINDOW_TIME)      // max. Samples per Time slice
@@ -223,7 +233,7 @@ ResetSampleFrequency ( long samplefreq ) {
         default:    return INIT_GAIN_ANALYSIS_ERROR;
     }
 
-    sampleWindow = (int) ceil (samplefreq * RMS_WINDOW_TIME);
+    sampleWindow = (int) ceil (samplefreq * RMS_WINDOW_TIME_FLOAT);
 
     lsum         = 0.;
     rsum         = 0.;
