@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
  * USA
  *
  */
@@ -25,13 +25,11 @@
 #define GRIP_H
 
 #include "config.h"
-#include <gnome.h>
+#include <gtk/gtk.h>
 #include "cddev.h"
 #include "discdb.h"
 #include "pthread.h"
 #include "launch.h"
-#include "status_window.h"
-#include "eggtrayicon.h"
 
 #if defined(HAVE_CDDA_INTERFACE_H) || defined(HAVE_CDDA_CDDA_INTERFACE_H)
 #define CDPAR
@@ -77,6 +75,11 @@ typedef struct _grip_gui {
 
   GtkWidget *disc_name_label;
   GtkWidget *disc_artist_label;
+
+  GtkWidget *dbinfo_hbox;
+  GtkWidget *dbinfo_back_button;
+  GtkWidget *dbinfo_forward_button;
+
   GtkListStore *track_list_store;
   GtkWidget *track_list;
 
@@ -113,10 +116,6 @@ typedef struct _grip_gui {
   GtkWidget *volume_control;
   gboolean volvis;
 
-  StatusWindow *status_window;
-  StatusWindow *rip_status_window;
-  StatusWindow *encode_status_window;
-
   GtkWidget *play_sector_label;
 
   GtkWidget *partial_rip_box;
@@ -182,9 +181,7 @@ typedef struct _grip_gui {
   GtkWidget *play_pix[3];
   
   /* notification area widgets */
-  EggTrayIcon *tray_icon;
-  GtkTooltips *tray_tips;
-  GtkWidget *tray_ebox;
+  GtkStatusIcon *tray_icon;
   GtkWidget *tray_menu;
   GtkWidget *tray_menu_play;
   GtkWidget *tray_menu_pause;
@@ -355,13 +352,12 @@ typedef struct _grip_info {
   size_t all_enclast[MAX_NUM_CPU];
 } GripInfo;
 
-GtkWidget *GripNew(const gchar* geometry,char *device,char *scsi_device,
+GtkWidget *GripNew(char *device,char *scsi_device,
 		   char *config_filename, gboolean force_small,
 		   gboolean local_mode,gboolean no_redirect);
 void GripDie(GtkWidget *widget,gpointer data);
 void GripUpdate(GtkWidget *app);
 GtkWidget *MakeNewPage(GtkWidget *notebook,char *name);
-void LogStatus(GripInfo *ginfo,char *fmt,...);
 void Busy(GripGUI *uinfo);
 void UnBusy(GripGUI *uinfo);
 void CloseStuff(void *user_data);
