@@ -16,12 +16,10 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
-#include <sys/stat.h>
-#include <unistd.h>
 #include "grip.h"
 #include "gripcfg.h"
 #include "dialog.h"
@@ -47,26 +45,19 @@ static Ripper ripper_defaults[]={
   {"",""}
 };
 
-static MP3Encoder encoder_defaults[]={{"bladeenc","-%b -QUIT %w %m","mp3"},
-				      {"lame","-h --add-id3v2 --tt \"%n\" --ta \"%a\" --tl \"%d\" --ty \"%y\" --tn \"%t\" --tg \"%G\" -b %b %w %m","mp3"},
-				      {"l3enc","-br %b %w %m","mp3"},
-				      {"xingmp3enc","-B %b -Q %w","mp3"},
-				      {"mp3encode","-p 2 -l 3 -b %b %w %m",
-				       "mp3"},
-				      {"gogo","-b %b %w %m","mp3"},
-				      {"oggenc",
-				       "-o %m -a %a -l %d -t %n -b %b -N %t -G %G -d %y %w",
-				       "ogg"},
-				      {"flac","--best --replay-gain -T title=\"%n\" -T artist=\"%a\" -T album=\"%d\" -T date=\"%y\" -T tracknumber=\"%t\" -T genre=\"%G\"  -o %m %w","flac"},
-				      {"other","",""},
-				      {"",""}
-};
-
-static CFGEntry encoder_cfg_entries[]={
-  {"name",CFG_ENTRY_STRING,256,NULL},
-  {"cmdline",CFG_ENTRY_STRING,256,NULL},
-  {"exe",CFG_ENTRY_STRING,256,NULL},
-  {"extension",CFG_ENTRY_STRING,10,NULL}
+static MP3Encoder encoder_defaults[]={
+  {"oggenc", "-o %m -a %a -l %d -t %n -b %b %w -N %t -G %g -d %y", "ogg"},
+  {"bladeenc","-%b -QUIT %w %m", "mp3"},
+  {"lame","-h --add-id3v2 --tt \"%n\" --ta \"%a\" --tl \"%d\" --ty \"%y\" --tn \"%t\" --tg \"%G\" -b %b %w %m","mp3"},
+  {"l3enc","-br %b %w %m","mp3"},
+  {"xingmp3enc","-B %b -Q %w","mp3"},
+  {"mp3encode","-p 2 -l 3 -b %b %w %m", "mp3"},
+  {"gogo","-b %b %w %m","mp3"},
+  {"flac","--best --replay-gain -T title=\"%n\" -T artist=\"%a\" -T album=\"%d\" -T date=\"%y\" -T tracknumber=\"%t\" -T genre=\"%G\"  -o %m %w","flac"},
+  {"faac", "-b %b -o %m -w --artist %a --title %n --genre %G --album %d --track %t/%N --year %y %w", "m4a"},
+  {"opusenc", "--bitrate %b --artist %a --title %n --genre %G --album %d --date %y %w %m", "opus"},
+  {"other","",""},
+  {"","",""}
 };
 
 static void UseProxyChanged(GtkWidget *widget,gpointer data)
@@ -91,14 +82,12 @@ void MakeConfigPage(GripInfo *ginfo)
   GtkWidget *config_notebook;
   GtkWidget *configpage;
   GtkWidget *button;
-#ifndef GRIPCD
   GtkWidget *hsep;
   GtkWidget *hbox;
   GtkWidget *menu,*optmenu;
   GtkWidget *item;
   MP3Encoder *enc;
   Ripper *rip;
-#endif
 
   uinfo=&(ginfo->gui_info);
 
@@ -160,7 +149,6 @@ void MakeConfigPage(GripInfo *ginfo)
   gtk_notebook_append_page(GTK_NOTEBOOK(config_notebook),page,label);
   gtk_widget_show(page);
 
-#ifndef GRIPCD
   page=gtk_frame_new(NULL);
 
   notebook=gtk_notebook_new();
@@ -556,7 +544,6 @@ void MakeConfigPage(GripInfo *ginfo)
   label = gtk_label_new(_("ID3"));
   gtk_notebook_append_page(GTK_NOTEBOOK(config_notebook),page,label);
   gtk_widget_show(page);
-#endif
 
   page=gtk_frame_new(NULL);
 
@@ -806,7 +793,7 @@ static void RipperSelected(GtkWidget *widget,gpointer data)
 
 gboolean LoadRipperConfig(GripInfo *ginfo,int ripcfg)
 {
-  char buf[256];
+  char buf[512];
   CFGEntry rip_cfg_entries[]={
     RIP_CFG_ENTRIES
   };
@@ -815,15 +802,15 @@ gboolean LoadRipperConfig(GripInfo *ginfo,int ripcfg)
   if(ripcfg==0) return 0;
 #endif
 
-  sprintf(buf,"%s/%s-%s",getenv("HOME"),ginfo->config_filename,
-          ripper_defaults[ripcfg].name);
+  g_snprintf(buf, 512, "%s/%s-%s", g_get_home_dir(), ginfo->config_filename,
+            ripper_defaults[ripcfg].name);
 
   return (LoadConfig(buf,"GRIP",2,2,rip_cfg_entries)==1);
 }
 
 void SaveRipperConfig(GripInfo *ginfo,int ripcfg)
 {
-  char buf[256];
+  char buf[512];
   CFGEntry rip_cfg_entries[]={
     RIP_CFG_ENTRIES
   };
@@ -832,12 +819,12 @@ void SaveRipperConfig(GripInfo *ginfo,int ripcfg)
   if(ripcfg==0) return;
 #endif
 
-  sprintf(buf,"%s/%s-%s",getenv("HOME"),ginfo->config_filename,
-          ripper_defaults[ripcfg].name);
+  g_snprintf(buf, 512, "%s/%s-%s", g_get_home_dir(), ginfo->config_filename,
+            ripper_defaults[ripcfg].name);
 
   if(!SaveConfig(buf,"GRIP",2,rip_cfg_entries))
-    gnome_app_warning((GnomeApp *)ginfo->gui_info.app,
-                      _("Error: Unable to save ripper config."));
+    DisplayMsg(GTK_MESSAGE_WARNING, (GtkWindow *)ginfo->gui_info.app,
+               _("Error: Unable to save ripper config."));
 }
 
 static void EncoderSelected(GtkWidget *widget,gpointer data)
@@ -857,6 +844,9 @@ static void EncoderSelected(GtkWidget *widget,gpointer data)
 
   if(LoadEncoderConfig(ginfo,ginfo->selected_encoder)) {
     strcpy(buf,ginfo->mp3exename);
+    /* in addition to searching the path during rip and encode
+     * also do a path lookup of the executable during config switches */
+    FindExeInPath(ginfo->mp3exename, buf, sizeof(buf));
     gtk_entry_set_text(GTK_ENTRY(uinfo->mp3exename_entry),buf);
 
     strcpy(buf,ginfo->mp3cmdline);
@@ -885,75 +875,40 @@ static void EncoderSelected(GtkWidget *widget,gpointer data)
 
 gboolean LoadEncoderConfig(GripInfo *ginfo,int encodecfg)
 {
-  char buf[256];
+  char buf[512];
   CFGEntry encode_cfg_entries[]={
     ENCODE_CFG_ENTRIES
   };
 
-  sprintf(buf,"%s/%s-%s",getenv("HOME"),ginfo->config_filename,
-          encoder_defaults[encodecfg].name);
+  g_snprintf(buf, 512, "%s/%s-%s", g_get_home_dir(), ginfo->config_filename,
+            encoder_defaults[encodecfg].name);
 
   return (LoadConfig(buf,"GRIP",2,2,encode_cfg_entries)==1);
 }
 
 void SaveEncoderConfig(GripInfo *ginfo,int encodecfg)
 {
-  char buf[256];
+  char buf[512];
   CFGEntry encode_cfg_entries[]={
     ENCODE_CFG_ENTRIES
   };
 
-  sprintf(buf,"%s/%s-%s",getenv("HOME"),ginfo->config_filename,
-          encoder_defaults[encodecfg].name);
+  g_snprintf(buf, 512, "%s/%s-%s", g_get_home_dir(), ginfo->config_filename,
+            encoder_defaults[encodecfg].name);
 
   if(!SaveConfig(buf,"GRIP",2,encode_cfg_entries))
-    gnome_app_warning((GnomeApp *)ginfo->gui_info.app,
-                      _("Error: Unable to save encoder config."));
+    DisplayMsg(GTK_MESSAGE_WARNING, (GtkWindow *)ginfo->gui_info.app,
+               _("Error: Unable to save encoder config."));
 }
 
 void FindExeInPath(char *exename, char *buf, int bsize)
 {
-  char *path;
-  static char **PATH = 0;
+  gchar *absolute_path = g_find_program_in_path (exename);
 
-  if(!PATH) {
-    const char *env = g_getenv("PATH");
-
-    PATH = g_strsplit(env ? env : "/usr/local/bin:/usr/bin:/bin", ":", 0);
-  }
-
-  path = FindExe(exename, PATH);
-
-  if(!path) {
+  if (absolute_path) {
+    g_snprintf(buf, bsize, "%s", absolute_path);
+    g_free (absolute_path);
+  } else {
     g_snprintf(buf, bsize, "%s", exename);
   }
-  else {
-    g_snprintf(buf, bsize, "%s/%s", path, exename);
-  }
 }
-
-char *FindExe(char *exename,char **paths)
-{
-  char **path;
-  char buf[256];
-
-  path=paths;
-
-  while(*path) {
-    g_snprintf(buf,256,"%s/%s",*path,exename);
-
-    if(FileExists(buf)) return *path;
-
-    path++;
-  }
-
-  return NULL;
-}
-
-gboolean FileExists(char *filename)
-{
-  struct stat mystat;
-
-  return (stat(filename,&mystat)>=0);
-}
-
