@@ -16,14 +16,14 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
+#include <glib/gi18n.h>
 #include <stdio.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <gnome.h>
 #include "grip_id3.h"
 
 static void ID3Put(char *dest,char *src,int len,char *encoding);
@@ -33,7 +33,6 @@ static void ID3Put(char *dest,char *src,int len,char *encoding);
 
 ID3Genre id3_genres[] = {
   {"Alternative",20},
-  {"Anime",146},
   {"Blues",0},
   {"Classical",32},
   {"Country",2},
@@ -45,27 +44,37 @@ ID3Genre id3_genres[] = {
   {"Reggae",16},
   {"Rock",17},
   {"Other",12},
+  {"Abstract",148},
   {"Acapella",123},
-  {"Acid",34},
   {"Acid Jazz",74},
   {"Acid Punk",73},
+  {"Acid",34},
   {"Acoustic",99},
   {"AlternRock",40},
   {"Ambient",26},
+  {"Anime",145},
+  {"Art Rock",149},
+  {"Audio Theatre",184},
+  {"Audiobook",183},
   {"Avantgarde",90},
   {"Ballad",116},
+  {"Baroque",150},
   {"Bass",41},
   {"Beat",135},
   {"Bebob",85},
+  {"Bhangra",151},
   {"Big Band",96},
+  {"Big Beat",152},
   {"Black Metal",138},
   {"Bluegrass",89},
   {"Booty Bass",107},
+  {"Breakbeat",153},
   {"BritPop",132},
   {"Cabaret",65},
   {"Celtic",88},
   {"Chamber Music",104},
   {"Chanson",102},
+  {"Chillout",154},
   {"Chorus",97},
   {"Christian Gangsta Rap",136},
   {"Christian Rap",61},
@@ -77,76 +86,108 @@ ID3Genre id3_genres[] = {
   {"Contemporary Christian",140},
   {"Crossover",139},
   {"Cult",58},
-  {"Dance",3},
   {"Dance Hall",125},
+  {"Dance",3},
   {"Darkwave",50},
   {"Death Metal",22},
   {"Disco",4},
+  {"Downtempo",155},
   {"Dream",55},
   {"Drum & Bass",127},
   {"Drum Solo",122},
+  {"Dub",156},
+  {"Dubstep",189},
   {"Duet",120},
+  {"EBM",157},
   {"Easy Listening",98},
+  {"Eclectic",158},
+  {"Electro",159},
+  {"Electroclash",160},
   {"Electronic",52},
+  {"Emo",161},
   {"Ethnic",48},
-  {"Eurodance",54},
-  {"Euro-house",124},
   {"Euro-Techno",25},
+  {"Euro-house",124},
+  {"Eurodance",54},
+  {"Experimental",162},
   {"Fast Fusion",84},
-  {"Folklore",115},
   {"Folk/Rock",81},
+  {"Folklore",115},
   {"Freestyle",119},
   {"Funk",5},
   {"Fusion",30},
+  {"G-Funk",188},
   {"Game",36},
   {"Gangsta",59},
+  {"Garage",163},
+  {"Garage Rock",190},
+  {"Global",164},
   {"Goa",126},
   {"Gospel",38},
-  {"Gothic",49},
   {"Gothic Rock",91},
+  {"Gothic",49},
   {"Grunge",6},
-  {"Hardcore",129},
   {"Hard Rock",79},
+  {"Hardcore",129},
   {"Heavy Metal",137},
   {"Hip-Hop",7},
   {"House",35},
   {"Humour",100},
+  {"IDM",165},
+  {"Illbient",166},
+  {"Indie Rock",187},
   {"Indie",131},
   {"Industrial",19},
-  {"Instrumental",33},
+  {"Industro-Goth",167},
   {"Instrumental Pop",46},
   {"Instrumental Rock",47},
+  {"Instrumental",33},
+  {"JPop",146},
+  {"Jam Band",168},
   {"Jazz+Funk",29},
-  {"JPop",145},
   {"Jungle",63},
+  {"Krautrock",169},
   {"Latin",86},
+  {"Leftfield",170},
   {"Lo-Fi",71},
+  {"Lounge",171},
+  {"Math Rock",172},
   {"Meditative",45},
   {"Merengue",142},
   {"Musical",77},
   {"National Folk",82},
   {"Native American",64},
   {"Negerpunk",133},
+  {"Neoclassical",182},
+  {"Neue Deutsche Welle",185},
   {"New Age",10},
+  {"New Romantic",173},
   {"New Wave",66},
   {"Noise",39},
+  {"Nu-Breakz",174},
   {"Oldies",11},
   {"Opera",103},
+  {"Podcast",186},
   {"Polka",75},
   {"Polsk Punk",134},
   {"Pop-Folk",53},
   {"Pop/Funk",62},
   {"Porn Groove",109},
+  {"Post-Punk",175},
+  {"Post-Rock",176},
   {"Power Ballad",117},
   {"Pranks",23},
   {"Primus",108},
   {"Progressive Rock",92},
-  {"Psychadelic",67},
+  {"Psybient",191},
+  {"Psychedelic",67},
   {"Psychedelic Rock",93},
-  {"Punk",43},
+  {"Psytrance",177},
   {"Punk Rock",121},
-  {"Rave",68},
+  {"Punk",43},
   {"R&B",14},
+  {"Rave",68},
+  {"Reggaestep",192},
   {"Retro",76},
   {"Revival",87},
   {"Rhythmic Soul",118},
@@ -154,6 +195,7 @@ ID3Genre id3_genres[] = {
   {"Salsa",143},
   {"Samba",114},
   {"Satire",110},
+  {"Shoegaze",178},
   {"Showtunes",69},
   {"Ska",21},
   {"Slow Jam",111},
@@ -163,6 +205,7 @@ ID3Genre id3_genres[] = {
   {"Sound Clip",37},
   {"Soundtrack",24},
   {"Southern Rock",56},
+  {"Space Rock",179},
   {"Space",44},
   {"Speech",101},
   {"Swing",83},
@@ -173,14 +216,16 @@ ID3Genre id3_genres[] = {
   {"Techno",18},
   {"Techno-Industrial",51},
   {"Terror",130},
+  {"Thrash Metal",144},
   {"Top 40",60},
   {"Trailer",70},
   {"Trance",31},
-  {"Trash Metal",144},
   {"Tribal",72},
   {"Trip-Hop",27},
+  {"Trop Rock",180},
   {"Vocal",28},
-  {NULL,145}
+  {"World Music",181},
+  {NULL,193}
 };
 
 /* This array maps CDDB_ genre numbers to closest id3 genre */
@@ -236,7 +281,6 @@ gboolean ID3v2TagFile(char *filename, char *title, char *artist, char *album,
   ID3Frame *frames[ NUM_FRAMES ];
   int i;
   gboolean retval = TRUE;
-  luint frm_offset;
   mode_t mask;
   char *conv_str;
   gsize rb,wb;
@@ -244,7 +288,7 @@ gboolean ID3v2TagFile(char *filename, char *title, char *artist, char *album,
   tag = ID3Tag_New();
 
   if(tag) {
-    frm_offset=ID3Tag_Link(tag,filename);
+    ID3Tag_Link(tag,filename);
     /* GRR. No error. */
     
     for ( i = 0; i < NUM_FRAMES; i++ ) {
@@ -253,7 +297,7 @@ gboolean ID3v2TagFile(char *filename, char *title, char *artist, char *album,
       if ( frames[ i ] ) {
 	char *c_data = NULL;
 	char gen[ 6 ] = "(   )"; /* max unsigned char: 255 */
-	char trk[ 3 ] = "  "; /* max CDDA tracks: 99 */
+	char trk[ 4 ] = "  "; /* max CDDA tracks: 99 */
 	
 	switch( frameids[ i ] ) {
 	case ID3FID_TITLE:
@@ -283,7 +327,7 @@ gboolean ID3v2TagFile(char *filename, char *title, char *artist, char *album,
 	  
 	case ID3FID_TRACKNUM:
 	  c_data = trk;
-	  snprintf( trk, 3, "%d", tracknum );
+	  snprintf( trk, 4, "%d", tracknum );
 	  break;
 	  
 	default:
