@@ -16,28 +16,23 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
 #include <config.h>
-#include <gnome.h>
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
 #include <stdlib.h>
 
 #include "grip.h"
 
-static gint KillSession(GnomeClient* client, gpointer client_data);
-static gint SaveSession(GnomeClient *client, gint phase, 
-			GnomeSaveStyle save_style,
-			gint is_shutdown, GnomeInteractStyle interact_style,
-			gint is_fast, gpointer client_data);
 static gint TimeOut(gpointer data);
 
 gboolean do_debug=TRUE;
 GtkWidget* grip_app;
 
 /* popt table */
-static char *geometry=NULL;
 static char *config_filename=NULL;
 static char *device=NULL;
 static char *scsi_device=NULL;
@@ -46,88 +41,82 @@ static int local_mode=FALSE;
 static int no_redirect=FALSE;
 static int verbose=FALSE;
 
-struct poptOption options[] = {
-  { 
-    "geometry",
-    '\0',
-    POPT_ARG_STRING,
-    &geometry,
-    0,
-    N_("Specify the geometry of the main window"),
-    N_("GEOMETRY")
-  },
+G_GNUC_NORETURN static gboolean
+option_version_cb(const gchar  *option_name,
+                  const gchar  *value,
+                  gpointer      data,
+                  GError      **error)
+{
+  g_print("%s %s\n", PACKAGE, VERSION);
+  exit(0);
+}
+
+static const GOptionEntry options[] = {
   {
     "config",
-    '\0',
-    POPT_ARG_STRING,
+    'c', 0,
+    G_OPTION_ARG_STRING,
     &config_filename,
-    0,
     N_("Specify the config file to use (in your home dir)"),
     N_("CONFIG")
   },
-  { 
+  {
     "device",
-    '\0',
-    POPT_ARG_STRING,
+    'd', 0,
+    G_OPTION_ARG_STRING,
     &device,
-    0,
     N_("Specify the cdrom device to use"),
     N_("DEVICE")
   },
-  { 
+  {
     "scsi-device",
-    '\0',
-    POPT_ARG_STRING,
+    0, 0,
+    G_OPTION_ARG_STRING,
     &scsi_device,
-    0,
     N_("Specify the generic scsi device to use"),
     N_("DEVICE")
   },
-  { 
+  {
     "small",
-    '\0',
-    POPT_ARG_NONE,
+    's', 0,
+    G_OPTION_ARG_NONE,
     &force_small,
-    0,
     N_("Launch in \"small\" (cd-only) mode"),
     NULL
   },
-  { 
+  {
     "local",
-    '\0',
-    POPT_ARG_NONE,
+    'l', 0,
+    G_OPTION_ARG_NONE,
     &local_mode,
-    0,
     N_("\"Local\" mode -- do not look up disc info on the net"),
     NULL
   },
-  { 
+  {
     "no-redirect",
-    '\0',
-    POPT_ARG_NONE,
+    0, 0,
+    G_OPTION_ARG_NONE,
     &no_redirect,
-    0,
     N_("Do not do I/O redirection"),
     NULL
   },
-  { 
+  {
     "verbose",
-    '\0',
-    POPT_ARG_NONE,
+    'v', 0,
+    G_OPTION_ARG_NONE,
     &verbose,
-    0,
     N_("Run in verbose (debug) mode"),
     NULL
   },
   {
-    NULL,
-    '\0',
-    0,
-    NULL,
-    0,
+    "version",
+    0, G_OPTION_FLAG_NO_ARG | G_OPTION_FLAG_HIDDEN,
+    G_OPTION_ARG_CALLBACK,
+    option_version_cb,
     NULL,
     NULL
-  }
+  },
+  { NULL }
 };
 
 void Debug(char *fmt,...)
@@ -150,7 +139,7 @@ void Debug(char *fmt,...)
 
 int Cmain(int argc, char* argv[])
 {
-  GnomeClient *client;
+  GOptionContext *context;
 
   /* Unbuffer stdout */
   setvbuf(stdout, 0, _IONBF, 0);
@@ -160,28 +149,22 @@ int Cmain(int argc, char* argv[])
   bindtextdomain(GETTEXT_PACKAGE,GNOMELOCALEDIR);
   textdomain(GETTEXT_PACKAGE);
 
-  gnome_program_init(PACKAGE,VERSION,LIBGNOMEUI_MODULE,argc,argv, 
-		     GNOME_PARAM_POPT_TABLE,options,
-		     GNOME_PROGRAM_STANDARD_PROPERTIES,NULL);
+  context = g_option_context_new (NULL);
+  g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
+  g_option_context_set_ignore_unknown_options (context, TRUE);
+  g_option_context_parse (context, &argc, &argv, NULL);
+
+  gtk_init(&argc, &argv);
 
   bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF8");
   setenv("CHARSET","UTF-8",1);
 
-  /* Session Management */
-  
-  client=gnome_master_client();
-  gtk_signal_connect(GTK_OBJECT(client),"save_yourself",
-		     GTK_SIGNAL_FUNC(SaveSession),argv[0]);
-  gtk_signal_connect(GTK_OBJECT(client),"die",
-		     GTK_SIGNAL_FUNC(KillSession),NULL);
-  
-
   do_debug=verbose;
 
   if(scsi_device) printf("scsi=[%s]\n",scsi_device);
 
   /* Start a new Grip app */
-  grip_app=GripNew(geometry,device,scsi_device,config_filename,
+  grip_app=GripNew(device,scsi_device,config_filename,
 		   force_small,local_mode,
 		   no_redirect);
 
@@ -194,35 +177,6 @@ int Cmain(int argc, char* argv[])
   return 0;
 }
 
-/* Save the session */
-static gint SaveSession(GnomeClient *client, gint phase,
-			GnomeSaveStyle save_style,
-			gint is_shutdown, GnomeInteractStyle interact_style,
-			gint is_fast, gpointer client_data)
-{
-  gchar** argv;
-  guint argc;
-
-  /* allocate 0-filled, so it will be NULL-terminated */
-  argv = g_malloc0(sizeof(gchar*)*4);
-  argc = 1;
-
-  argv[0] = client_data;
-
-  gnome_client_set_clone_command(client, argc, argv);
-  gnome_client_set_restart_command(client, argc, argv);
-
-  return TRUE;
-}
-
-/* Kill Session */
-static gint KillSession(GnomeClient* client, gpointer client_data)
-{
-  gtk_main_quit();
-
-  return TRUE;
-}
-
 static gint TimeOut(gpointer data)
 {
   GripUpdate(grip_app);
