@@ -16,10 +16,12 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
+#include <gtk/gtk.h>
+#include <glib/gi18n.h>
 #include "cdplay.h"
 #include "tray.h"
 #include "rip.h"
@@ -66,7 +68,7 @@ void UpdateTray(GripInfo *ginfo)
 			MakeTrayIcon(ginfo);
 	} else {
 		if (uinfo->tray_icon) {
-			gtk_widget_destroy(GTK_WIDGET(uinfo->tray_icon));
+			g_object_unref(uinfo->tray_icon);
 			uinfo->tray_icon = NULL;
 		}
 		ginfo->tray_icon_made = FALSE;
@@ -84,19 +86,19 @@ void UpdateTray(GripInfo *ginfo)
 		} else if (!ginfo->playing) {
 			if (ginfo->ripping || ginfo->encoding) {
 				TrayGrayMenu(ginfo);
-				riptext = (ginfo->ripping) ? g_strdup_printf(_("Ripping  Track %02d:\t%6.2f%% (%6.2f%% )"), ginfo->rip_track + 1, ginfo->rip_percent * 100, ginfo->rip_tot_percent * 100) : g_strdup_printf("");
-			    enctext = (ginfo->encoding) ? g_strdup_printf(_("Encoding Track %02d:\t%6.2f%% (%6.2f%% )"), ginfo->mp3_enc_track[0] + 1, ginfo->enc_percent * 100, ginfo->enc_tot_percent * 100) : g_strdup_printf("");
+				riptext = (ginfo->ripping) ? g_strdup_printf(_("Ripping  Track %02d:\t%6.2f%% (%6.2f%% )"), ginfo->rip_track + 1, ginfo->rip_percent * 100, ginfo->rip_tot_percent * 100) : g_strdup("");
+			    enctext = (ginfo->encoding) ? g_strdup_printf(_("Encoding Track %02d:\t%6.2f%% (%6.2f%% )"), ginfo->mp3_enc_track[0] + 1, ginfo->enc_percent * 100, ginfo->enc_tot_percent * 100) : g_strdup("");
 				text = g_strdup_printf(_("%s - %s\n%s%s%s"), artist, title, riptext, (ginfo->ripping && ginfo->encoding) ? "\n" : "", enctext);
 			} else {
 				TrayUnGrayMenu(ginfo);
 				text = g_strdup_printf(_("%s - %s\nIdle"), artist, title);
 			}
 		}
-	
-		gtk_tooltips_set_tip(GTK_TOOLTIPS(uinfo->tray_tips), uinfo->tray_ebox, text, NULL);
-	
-		if (riptext) g_free(riptext);
-		if (enctext) g_free(enctext);
+
+		gtk_status_icon_set_tooltip_text (uinfo->tray_icon, text);
+
+		g_free(riptext);
+		g_free(enctext);
 		g_free(text);
 	}
 }
@@ -131,7 +133,7 @@ void TrayMenuShowPause(GripInfo *ginfo)
 
 static void ToggleMenuItemSensitive(GtkWidget *widget, gpointer data)
 {
-	gtk_widget_set_sensitive(GTK_WIDGET(widget), (gboolean)data);
+	gtk_widget_set_sensitive(GTK_WIDGET(widget), GPOINTER_TO_INT(data));
 }
 
 void TrayGrayMenu(GripInfo *ginfo)
@@ -163,76 +165,62 @@ void TrayUnGrayMenu(GripInfo *ginfo)
 
 static void MakeTrayIcon(GripInfo *ginfo)
 {
-	GtkWidget *image, *mentry, *hb, *img;
+	GtkWidget *mentry, *hb, *img;
 	GripGUI *uinfo = &(ginfo->gui_info);
-	
-	uinfo->tray_icon = egg_tray_icon_new("Grip");	
-	
-	uinfo->tray_ebox = gtk_event_box_new();
-	
-	gtk_container_set_border_width(GTK_CONTAINER(uinfo->tray_icon), 0);
-	
-	gtk_container_add(GTK_CONTAINER(uinfo->tray_icon), uinfo->tray_ebox);
-		
-	image = gtk_image_new_from_file(GNOME_ICONDIR"/griptray.png");
-	
-	gtk_container_add(GTK_CONTAINER(uinfo->tray_ebox), image);
-	
-	uinfo->tray_tips = gtk_tooltips_new();
-	
+
+	uinfo->tray_icon = gtk_status_icon_new_from_file(GNOME_ICONDIR"/griptray.png");
+
 	uinfo->tray_menu = gtk_menu_new();
-	
+
 	img = (GtkWidget*)Loadxpm(uinfo->app, menuplay_xpm);
 	uinfo->tray_menu_play = (GtkWidget*)BuildMenuItemXpm(img, _("Play"));
 	g_signal_connect(uinfo->tray_menu_play, "activate", G_CALLBACK(PlayCB), ginfo);
 	gtk_menu_shell_append(GTK_MENU_SHELL(uinfo->tray_menu), uinfo->tray_menu_play);
-	
+
 	img = (GtkWidget*)Loadxpm(uinfo->app, menupause_xpm);
 	uinfo->tray_menu_pause = (GtkWidget*)BuildMenuItemXpm(img, _("Pause"));
 	g_signal_connect(uinfo->tray_menu_pause, "activate", G_CALLBACK(PauseCB), ginfo);
 	gtk_menu_shell_append(GTK_MENU_SHELL(uinfo->tray_menu), uinfo->tray_menu_pause);
-	
+
 	img = (GtkWidget*)Loadxpm(uinfo->app, menustop_xpm);
 	mentry = (GtkWidget*)BuildMenuItemXpm(img, _("Stop"));
 	g_signal_connect(mentry, "activate", G_CALLBACK(StopCB), ginfo);
 	gtk_menu_shell_append(GTK_MENU_SHELL(uinfo->tray_menu), mentry);
-	
+
 	hb = gtk_separator_menu_item_new();
 	gtk_menu_shell_append(GTK_MENU_SHELL(uinfo->tray_menu), hb);
-	
+
 	img = (GtkWidget*)Loadxpm(uinfo->app, menuprev_xpm);
 	mentry = (GtkWidget*)BuildMenuItemXpm(img, _("Previous"));
 	g_signal_connect(mentry, "activate", G_CALLBACK(PrevCB), ginfo);
 	gtk_menu_shell_append(GTK_MENU_SHELL(uinfo->tray_menu), mentry);
-	
+
 	img = (GtkWidget*)Loadxpm(uinfo->app, menunext_xpm);
 	mentry = (GtkWidget*)BuildMenuItemXpm(img, _("Next"));
 	g_signal_connect(mentry, "activate", G_CALLBACK(NextCB), ginfo);
 	gtk_menu_shell_append(GTK_MENU_SHELL(uinfo->tray_menu), mentry);
-	
+
 	hb = gtk_separator_menu_item_new();
 	gtk_menu_shell_append(GTK_MENU_SHELL(uinfo->tray_menu), hb);
-	
+
 	img = (GtkWidget*)Loadxpm(uinfo->app, rip1_xpm);
 	mentry = (GtkWidget*)BuildMenuItemXpm(img, _("Rip and Encode"));
 	g_signal_connect(mentry, "activate", G_CALLBACK(RipEncCB), ginfo);
 	gtk_menu_shell_append(GTK_MENU_SHELL(uinfo->tray_menu), mentry);
-	
+
 	hb = gtk_separator_menu_item_new();
 	gtk_menu_shell_append(GTK_MENU_SHELL(uinfo->tray_menu), hb);
 
 	mentry = (GtkWidget*)BuildMenuItem(GTK_STOCK_QUIT, _("Quit"), TRUE);
 	g_signal_connect(mentry, "activate", G_CALLBACK(QuitCB), ginfo);
 	gtk_menu_shell_append(GTK_MENU_SHELL(uinfo->tray_menu), mentry);
-		
-	g_signal_connect(uinfo->tray_ebox, "button-press-event", G_CALLBACK(TrayIconButtonPress), ginfo);
-	
+
+	g_signal_connect(uinfo->tray_icon, "button-press-event", G_CALLBACK(TrayIconButtonPress), ginfo);
+
 	gtk_widget_show_all(uinfo->tray_menu);
-	
+
 	gtk_widget_hide(uinfo->tray_menu_pause);
-	
-	gtk_widget_show_all(GTK_WIDGET(uinfo->tray_icon));	
-		
+
 	ginfo->tray_icon_made = TRUE;
 }
 
@@ -259,9 +247,11 @@ static gboolean TrayIconButtonPress(GtkWidget *widget, GdkEventButton *event, gp
 				
 		return TRUE;
 	}
-		
+
 	if (event->button == 3) {
-		gtk_menu_popup(GTK_MENU(uinfo->tray_menu), NULL, NULL, NULL, NULL, event->button, event->time);
+		gtk_menu_popup(GTK_MENU(uinfo->tray_menu), NULL, NULL,
+		               gtk_status_icon_position_menu, uinfo->tray_icon,
+		               event->button, event->time);
 		
 		return TRUE;
 	}
