@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
@@ -50,7 +50,6 @@
 #include "../pixmaps/mail.xpm"
 #include "../pixmaps/save.xpm"
 
-#ifndef GRIPCD
 #include "../pixmaps/grip.xpm"
 #include "../pixmaps/enc0.xpm"
 #include "../pixmaps/enc1.xpm"
@@ -68,6 +67,3 @@
 #include "../pixmaps/smile6.xpm"
 #include "../pixmaps/smile7.xpm"
 #include "../pixmaps/smile8.xpm"
-#else
-#include "../pixmaps/gcd.xpm"
-#endif
